<?php
/**
 * Recommends plugins for use with the theme via the TGMA Script
 *
 * @package Aaraa WordPress theme
 */

function aaraa_tgmpa_plugins_register() {

	// Get array of recommended plugins.
    $theme_required_plugin_lists = array();
    $url = 'https://api.wordpress.org/plugins/info/1.0/unyson';
    $api_response = wp_remote_get( $url );
    if ( is_array( $api_response ) && ! is_wp_error( $api_response ) ) {
        if( isset($api_response['response']) && !empty($api_response['response']) ) {
            if ( 404 == $api_response['response']['code'] && 'Not Found' == $api_response['response']['message'] ) {
                $unyson_plugin = array(
                    array(
                        'name'               => esc_html__('Unyson', 'aaraa'),
                        'slug'               => 'unyson',
                        'source'             => AARAA_MODULE_DIR . '/plugins/unyson.zip',
                        'required'           => true,
                        'version'            => '2.7.28',
                        'force_activation'   => false,
                        'force_deactivation' => false,
                    )
                );
            } else {
                $unyson_plugin = array(
                    array(
                        'name'     => esc_html__('Unyson', 'aaraa'),
                        'slug'     => 'unyson',
                        'required' => true,
                    )
                );
            }
        }
    }
	$plugins_list = array(
        array(
            'name'               => esc_html__('Aaraa Plus', 'aaraa'),
            'slug'               => 'aaraa-plus',
            'source'             => AARAA_MODULE_DIR . '/plugins/aaraa-plus.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('Aaraa Pro', 'aaraa'),
            'slug'               => 'aaraa-pro',
            'source'             => AARAA_MODULE_DIR . '/plugins/aaraa-pro.zip',
            'required'           => true,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('Elementor', 'aaraa'),
            'slug'     => 'elementor',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Elementor Addon', 'aaraa'),
            'slug'               => 'wedesigntech-elementor-addon',
            'source'             => AARAA_MODULE_DIR . '/plugins/wedesigntech-elementor-addon.zip',
            'required'           => true,
            'version'            => '1.0.2',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Portfolio', 'aaraa'),
            'slug'               => 'wedesigntech-portfolio',
            'source'             => AARAA_MODULE_DIR . '/plugins/wedesigntech-portfolio.zip',
            'required'           => false,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('WooCommerce', 'aaraa'),
            'slug'     => 'woocommerce',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('Aaraa Shop', 'aaraa'),
            'slug'               => 'aaraa-shop',
            'source'             => AARAA_MODULE_DIR . '/plugins/aaraa-shop.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Wishlist', 'aaraa'),
            'slug'     => 'yith-woocommerce-wishlist',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Compare', 'aaraa'),
            'slug'     => 'yith-woocommerce-compare',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('Contact Form 7', 'aaraa'),
            'slug'     => 'contact-form-7',
            'required' => true,
        )
	);
    $theme_required_plugin_lists = array_merge( $unyson_plugin, $plugins_list );
    $plugins = apply_filters('aaraa_required_plugins_list', $theme_required_plugin_lists);

	// Register notice
	tgmpa( $plugins, array(
		'id'           => 'aaraa_theme',
		'domain'       => 'aaraa',
		'menu'         => 'install-required-plugins',
		'has_notices'  => true,
		'is_automatic' => true,
		'dismissable'  => true,
	) );

}
add_action( 'tgmpa_register', 'aaraa_tgmpa_plugins_register' );